pub struct BodyWriter<'a> { /* private fields */ }
A writer that writes to a Unit shared memory response buffer.

This object is created using Request::write_chunks() or Request::send_chunks_with_writer().

A chunk will be immediately sent to the client once the writer’s memory buffer reaches chunk_size, or flush() is called on the writer, and a new shared memory buffer will be allocated.

The writer will also flush when dropped, but any errors that happen during a drop will panic.

Implementations

Copy from a reader to this writer without using an intermediary buffer.

Normally the Write trait receives an input buffer to copy from, and the ResponseWriter writer will copy from it into Unit’s shared memory.

This method will instead give Unit’s shared memory buffer directly to the Read trait in order to skip copying to a third temporary buffer (such as when using std::io::copy).