pub trait UnitService {
    fn handle_request(&mut self, req: Request<'_>) -> UnitResult<()>;
}
A trait that can be implemented by request handlers to be used with Unit::set_request_handler().

This trait is automatically implemented for functions or lambda functions that take a Request object and return a UnitResult<()>.

Required Methods

Implementors