pub struct Unit { /* private fields */ }
The Unit application context.

This object wraps the libunit library, which talks to the Unit server over shared memory and a unix socket in order to receive data about requests.

Implementations

Create a new Unit context and initialize the Unit application.

Note: Only one Unit object may be active in a single process.

Set a request handler for the Unit application.

The handler must be a function or lambda function that takes a UnitRequest object and returns a UnitResult<()>.

Enter the main event loop, handling requests until the Unit server exits or requests a restart.